==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/ColumnSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { HorizontalAnchoredCategorySeriesDescription } from "./HorizontalAnchoredCategorySeriesDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var ColumnSeriesDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ColumnSeriesDescription, _super);
    function ColumnSeriesDescription() {
        var _this = _super.call(this) || this;
        _this.er = 0;
        _this.es = 0;
        _this.ev = null;
        return _this;
    }
    ColumnSeriesDescription.prototype.get_type = function () {
        return "ColumnSeries";
    };
    Object.defineProperty(ColumnSeriesDescription.prototype, "radiusX", {
        get: function () {
            return this.er;
        },
        set: function (a) {
            this.er = a;
            this.e("RadiusX");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ColumnSeriesDescription.prototype, "radiusY", {
        get: function () {
            return this.es;
        },
        set: function (a) {
            this.es = a;
            this.e("RadiusY");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ColumnSeriesDescription.prototype, "consolidatedColumnVerticalPosition", {
        get: function () {
            return this.ev;
        },
        set: function (a) {
            this.ev = a;
            this.e("ConsolidatedColumnVerticalPosition");
        },
        enumerable: true,
        configurable: true
    });
    ColumnSeriesDescription.$t = markType(ColumnSeriesDescription, 'ColumnSeriesDescription', HorizontalAnchoredCategorySeriesDescription.$);
    return ColumnSeriesDescription;
}(HorizontalAnchoredCategorySeriesDescription));
export { ColumnSeriesDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/ColumnSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { HorizontalAnchoredCategorySeriesDescription } from "./HorizontalAnchoredCategorySeriesDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var ColumnSeriesDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ColumnSeriesDescription, _super);
    function ColumnSeriesDescription() {
        var _this = _super.call(this) || this;
        _this.gz = 0;
        _this.g0 = 0;
        _this.g3 = null;
        return _this;
    }
    ColumnSeriesDescription.prototype.get_type = function () {
        return "ColumnSeries";
    };
    Object.defineProperty(ColumnSeriesDescription.prototype, "radiusX", {
        get: function () {
            return this.gz;
        },
        set: function (a) {
            this.gz = a;
            this.g("RadiusX");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ColumnSeriesDescription.prototype, "radiusY", {
        get: function () {
            return this.g0;
        },
        set: function (a) {
            this.g0 = a;
            this.g("RadiusY");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ColumnSeriesDescription.prototype, "consolidatedColumnVerticalPosition", {
        get: function () {
            return this.g3;
        },
        set: function (a) {
            this.g3 = a;
            this.g("ConsolidatedColumnVerticalPosition");
        },
        enumerable: false,
        configurable: true
    });
    ColumnSeriesDescription.$t = markType(ColumnSeriesDescription, 'ColumnSeriesDescription', HorizontalAnchoredCategorySeriesDescription.$);
    return ColumnSeriesDescription;
}(HorizontalAnchoredCategorySeriesDescription));
export { ColumnSeriesDescription };
